@@ -5,13 +5,13 @@ static int trace_sysnum(void)
 
 static long trace_raw_ret(void *vregs)
 {
-	struct user_regs_struct *regs = vregs;
+	trace_regs *regs = vregs;
 	return regs->eax;
 }
 
 static unsigned long trace_arg(void *vregs, int num)
 {
-	struct user_regs_struct *regs = vregs;
+	trace_regs *regs = vregs;
 	switch (num) {
 		case 1: return regs->ebx;
 		case 2: return regs->ecx;
