@@ -22,7 +22,6 @@ static int print_debug = 0;
 volatile static int stop_called = 0;
 volatile static pid_t child_pid = 0;
 
-static char log_domain[] = "sandbox";
 static const char sandbox_banner[] = "============================= Gentoo path sandbox ==============================";
 static const char sandbox_footer[] = "--------------------------------------------------------------------------------";
 
@@ -207,8 +206,6 @@ int main(int argc, char **argv)
 
 	char *run_str = "-c";
 
-	rc_log_domain(log_domain);
-
 	/* Only print info if called with no arguments .... */
 	if (argc < 2)
 		print_debug = 1;
