@@ -9,5 +9,5 @@ openat_static-0 3 AT_FDCWD ok O_RDONLY 0666 || exit 1
 export SANDBOX_LOG=$PWD/sb.log
 mkdir deny || exit 1
 adddeny $PWD/deny
-openat_static-0 -1 AT_FDCWD deny/not-ok O_WRONLY 0666
+openat_static-0 -1 AT_FDCWD deny/not-ok "O_WRONLY|O_CREAT" 0666
 test -e sb.log
